@@ -77,7 +77,6 @@ class RDSClient():
             print(f'select_query : ERROR : {e}')
             return False
 
-
     def insert_query(self,
                      query: str) -> object:
         """
@@ -93,6 +92,26 @@ class RDSClient():
             print(f'select_query : ERROR : {e}')
             return False
         
+    def get_object(self,
+                   table: str,
+                   id: int) -> dict:
+        """
+        """
+        if not table.startswith('neuralplatform_'):
+            table = 'neuralplatform_' + table
+        query = f"SELECT * FROM {table} WHERE id = {id};"
+        return self.select_query(query, fetchone=True)
+    
+    def get_objects(self,
+                    table: str,
+                    ids: list) -> list:
+        """
+        """
+        if not table.startswith('neuralplatform_'):
+            table = 'neuralplatform_' + table
+        query = f"SELECT * FROM {table} WHERE id IN {tuple(ids)};"
+        return self.select_query(query, fetchone=False)    
+        
     def get_project_version_documents(self,
                                       project_id: int,
                                       version_id: int) -> list:
@@ -121,7 +140,7 @@ class RDSClient():
         """
         """
         query = f"UPDATE neuralplatform_version v SET status = '{status}' WHERE v.id = {version_id};"
-        return self.update_query(query)        
+        return self.update_query(query)
 
     def get_document_name_and_uri(self,
                                   document_id: int) -> tuple:
@@ -207,3 +226,21 @@ class RDSClient():
         """
         query = f"SELECT * FROM neuralplatform_model WHERE version_id = {version_id};"
         return self.select_query(query, fetchone=True)
+
+    ## Automlapi functions
+    def get_pending_and_unblocked_steps(self):
+        """
+        """
+        query = 'SELECT * FROM neuralplatform_step WHERE status = "pending";'
+        pending_steps = self.select_query(query)
+        # Get definition dependencies, 
+        query = 'SELECT id, blockingStep_id FROM neuralplatform_stepdefinition;'
+        dependencies = { sd['id']: sd['blockingStep_id'] for sd in self.select_query(query) }
+        dependencies_satisfied = dict()
+        # Check if dependencies satisfied
+        for dependency, blocking_step_id in dependencies.items():
+            query = f"SELECT * FROM neuralplatform_step WHERE status NOT IN ('succeeded', 'error') AND stepDefinition_id = {blocking_step_id}"
+            satisfied = not ( bool( len(self.select_query(query)) ) )
+            dependencies_satisfied[dependency] = satisfied
+        # Return pending steps with dependencies satisfied
+        return [ step for step in pending_steps if dependencies_satisfied[step['id']] ]
