@@ -123,3 +123,12 @@ class S3Client(Boto3Client):
         """
         classes = self.get_object(Bucket=bucket, Key=f"{project_name}/config/classes.json")
         return json.loads(classes['Body'].read())
+
+    def create_account_bucket(self,
+                              name: str,
+                              region: str = 'eu-west-3') -> str:
+        """
+        """
+        bucket_name = f'np-{name}-bucket'
+        location = {'LocationConstraint': region}
+        self.create_bucket(Bucket=bucket_name, CreateBucketConfiguration=location)
